==> qtjambi-activex-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiActiveX/QAxScriptEngine_shell.h <==
#ifndef QAXSCRIPTENGINE_SHELL_H
#define QAXSCRIPTENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxscript.h>)
#include <ActiveQt/qaxscript.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxScriptEngine_shell : public QAxScriptEngine, public QtJambiShellInterface
{
public:
    QAxScriptEngine_shell(const QString& language0, QAxScript* script1);
    ~QAxScriptEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    const char* className() const override;
    void clear() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    const QMetaObject* fallbackMetaObject() const override;
    bool propertyWritable(const char* arg__1) const override;
    QObject* qObject() const override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__className_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxScriptEngine_access : public QAxScriptEngine
{
};

#endif // defined(Q_OS_WIN)
#endif // QAXSCRIPTENGINE_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiActiveX/QAxScriptEngine_shell.h <==
#ifndef QAXSCRIPTENGINE_SHELL_H
#define QAXSCRIPTENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <ActiveQt/qaxscript.h>
#include <QtJambi/QtJambiAPI>
#include <ActiveQt/qaxbase.h>
#include <ActiveQt/qaxobject.h>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAxScriptEngine_shell : public QAxScriptEngine, public QtJambiShellInterface
{
public:
    QAxScriptEngine_shell(const QString& language0, QAxScript* script1);
    ~QAxScriptEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool propertyWritable(const char* arg__1) const override;
    void resetControl() override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxScriptEngine_access : public QAxScriptEngine
{
};

#endif // QAXSCRIPTENGINE_SHELL_H
